@@ -43,7 +43,7 @@ pub(crate) fn delivery_targets(
     if !section.is_elder(our_name) {
         // We are not Elder - return all the elders of our section, so the message can be properly
         // relayed through them.
-        let targets: Vec<_> = section.elders_info().peers().copied().collect();
+        let targets: Vec<_> = section.authority_provider().peers().collect();
         let dg_size = targets.len();
         return Ok((targets, dg_size));
     }
@@ -61,7 +61,7 @@ pub(crate) fn delivery_targets(
                 return Ok((Vec::new(), 0));
             }
             if let Some(node) = get_peer(target_name, section, network) {
-                return Ok((vec![*node], 1));
+                return Ok((vec![node], 1));
             }
 
             candidates(target_name, our_name, section, network)?
@@ -79,17 +79,16 @@ fn section_candidates(
     network: &Network,
 ) -> Result<(Vec<Peer>, usize)> {
     // Find closest section to `target_name` out of the ones we know (including our own)
-    let info = iter::once(section.elders_info())
+    let info = iter::once(section.authority_provider())
         .chain(network.all())
         .min_by(|lhs, rhs| lhs.prefix.cmp_distance(&rhs.prefix, target_name))
-        .unwrap_or_else(|| section.elders_info());
+        .unwrap_or_else(|| section.authority_provider());
 
     if info.prefix == *section.prefix() {
         // Exclude our name since we don't need to send to ourself
         let section: Vec<_> = info
             .peers()
             .filter(|node| node.name() != our_name)
-            .copied()
             .collect();
         let dg_size = section.len();
         return Ok((section, dg_size));
@@ -106,17 +105,17 @@ fn candidates(
     network: &Network,
 ) -> Result<(Vec<Peer>, usize)> {
     // All sections we know (including our own), sorted by distance to `target_name`.
-    let sections = iter::once(section.elders_info())
+    let sections = iter::once(section.authority_provider())
         .chain(network.all())
         .sorted_by(|lhs, rhs| lhs.prefix.cmp_distance(&rhs.prefix, target_name))
-        .map(|info| (&info.prefix, info.elders.len(), info.elders.values()));
+        .map(|info| (&info.prefix, info.elders.len(), info.peers()));
 
     // gives at least 1 honest target among recipients.
     let min_dg_size = 1 + ELDER_SIZE - supermajority(ELDER_SIZE);
     let mut dg_size = min_dg_size;
     let mut candidates = Vec::new();
     for (idx, (prefix, len, connected)) in sections.enumerate() {
-        candidates.extend(connected.cloned());
+        candidates.extend(connected);
         if prefix.matches(target_name) {
             // If we are last hop before final dst, send to all candidates.
             dg_size = len;
@@ -153,11 +152,11 @@ fn candidates(
 }
 
 // Returns a `Peer` for a known node.
-fn get_peer<'a>(name: &XorName, section: &'a Section, network: &'a Network) -> Option<&'a Peer> {
+fn get_peer(name: &XorName, section: &Section, network: &Network) -> Option<Peer> {
     section
         .members()
         .get(name)
-        .map(|info| &info.peer)
+        .map(|info| info.peer)
         .or_else(|| network.get_elder(name))
 }
 
@@ -168,8 +167,8 @@ mod tests {
         agreement::test_utils::proven,
         crypto,
         section::{
-            test_utils::{gen_addr, gen_elders_info},
-            EldersInfo, MemberInfo, SectionChain, MIN_ADULT_AGE,
+            test_utils::{gen_addr, gen_section_authority_provider},
+            MemberInfo, SectionAuthorityProvider, SectionChain, MIN_ADULT_AGE,
         },
     };
     use anyhow::{Context, Result};
@@ -181,7 +180,7 @@ mod tests {
         let (our_name, section, network, _) = setup_elder()?;
 
         let dst_name = *section
-            .elders_info()
+            .authority_provider()
             .elders
             .keys()
             .filter(|&&name| name != our_name)
@@ -229,11 +228,11 @@ mod tests {
 
         // Send to all our elders except us.
         let expected_recipients = section
-            .elders_info()
+            .authority_provider()
             .peers()
             .filter(|peer| peer.name() != &our_name);
         assert_eq!(dg_size, expected_recipients.clone().count());
-        itertools::assert_equal(&recipients, expected_recipients);
+        itertools::assert_equal(recipients, expected_recipients);
 
         Ok(())
     }
@@ -242,11 +241,11 @@ mod tests {
     fn delivery_targets_elder_to_known_remote_peer() -> Result<()> {
         let (our_name, section, network, _) = setup_elder()?;
 
-        let elders_info1 = network
+        let section_auth1 = network
             .get(&Prefix::default().pushed(true))
             .context("unknown section")?;
 
-        let dst_name = choose_elder_name(elders_info1)?;
+        let dst_name = choose_elder_name(section_auth1)?;
         let dst = DstLocation::Node(dst_name);
         let (recipients, dg_size) = delivery_targets(&dst, &our_name, &section, &network)?;
 
@@ -261,20 +260,20 @@ mod tests {
     fn delivery_targets_elder_to_final_hop_unknown_remote_peer() -> Result<()> {
         let (our_name, section, network, _) = setup_elder()?;
 
-        let elders_info1 = network
+        let section_auth1 = network
             .get(&Prefix::default().pushed(true))
             .context("unknown section")?;
 
-        let dst_name = elders_info1.prefix.substituted_in(rand::random());
+        let dst_name = section_auth1.prefix.substituted_in(rand::random());
         let dst = DstLocation::Node(dst_name);
         let (recipients, dg_size) = delivery_targets(&dst, &our_name, &section, &network)?;
 
         // Send to all elders in the dst section
-        let expected_recipients = elders_info1
+        let expected_recipients = section_auth1
             .peers()
             .sorted_by(|lhs, rhs| dst_name.cmp_distance(lhs.name(), rhs.name()));
-        assert_eq!(dg_size, elders_info1.elders.len());
-        itertools::assert_equal(&recipients, expected_recipients);
+        assert_eq!(dg_size, section_auth1.elders.len());
+        itertools::assert_equal(recipients, expected_recipients);
 
         Ok(())
     }
@@ -301,7 +300,7 @@ mod tests {
             .sorted_by(|lhs, rhs| dst_name.cmp_distance(lhs.name(), rhs.name()));
         let min_dg_size = 1 + elders_info1.elders.len() - supermajority(elders_info1.elders.len());
         assert_eq!(dg_size, min_dg_size);
-        itertools::assert_equal(&recipients, expected_recipients);
+        itertools::assert_equal(recipients, expected_recipients);
 
         Ok(())
     }
@@ -310,20 +309,20 @@ mod tests {
     fn delivery_targets_elder_final_hop_to_remote_section() -> Result<()> {
         let (our_name, section, network, _) = setup_elder()?;
 
-        let elders_info1 = network
+        let section_auth1 = network
             .get(&Prefix::default().pushed(true))
             .context("unknown section")?;
 
-        let dst_name = elders_info1.prefix.substituted_in(rand::random());
+        let dst_name = section_auth1.prefix.substituted_in(rand::random());
         let dst = DstLocation::Section(dst_name);
         let (recipients, dg_size) = delivery_targets(&dst, &our_name, &section, &network)?;
 
         // Send to all elders in the final dst section
-        let expected_recipients = elders_info1
+        let expected_recipients = section_auth1
             .peers()
             .sorted_by(|lhs, rhs| dst_name.cmp_distance(lhs.name(), rhs.name()));
-        assert_eq!(dg_size, elders_info1.elders.len());
-        itertools::assert_equal(&recipients, expected_recipients);
+        assert_eq!(dg_size, section_auth1.elders.len());
+        itertools::assert_equal(recipients, expected_recipients);
 
         Ok(())
     }
@@ -352,7 +351,7 @@ mod tests {
             .take(min_dg_size);
 
         assert_eq!(dg_size, min_dg_size);
-        itertools::assert_equal(&recipients, expected_recipients);
+        itertools::assert_equal(recipients, expected_recipients);
 
         Ok(())
     }
@@ -361,13 +360,13 @@ mod tests {
     fn delivery_targets_adult_to_our_elder() -> Result<()> {
         let (our_name, section, network) = setup_adult()?;
 
-        let dst_name = choose_elder_name(section.elders_info())?;
+        let dst_name = choose_elder_name(section.authority_provider())?;
         let dst = DstLocation::Node(dst_name);
         let (recipients, dg_size) = delivery_targets(&dst, &our_name, &section, &network)?;
 
         // Send to all elders
-        assert_eq!(dg_size, section.elders_info().elders.len());
-        itertools::assert_equal(&recipients, section.elders_info().peers());
+        assert_eq!(dg_size, section.authority_provider().elders.len());
+        itertools::assert_equal(recipients, section.authority_provider().peers());
 
         Ok(())
     }
@@ -381,8 +380,8 @@ mod tests {
         let (recipients, dg_size) = delivery_targets(&dst, &our_name, &section, &network)?;
 
         // Send to all elders
-        assert_eq!(dg_size, section.elders_info().elders.len());
-        itertools::assert_equal(&recipients, section.elders_info().peers());
+        assert_eq!(dg_size, section.authority_provider().elders.len());
+        itertools::assert_equal(recipients, section.authority_provider().peers());
 
         Ok(())
     }
@@ -396,8 +395,8 @@ mod tests {
         let (recipients, dg_size) = delivery_targets(&dst, &our_name, &section, &network)?;
 
         // Send to all elders
-        assert_eq!(dg_size, section.elders_info().elders.len());
-        itertools::assert_equal(&recipients, section.elders_info().peers());
+        assert_eq!(dg_size, section.authority_provider().elders.len());
+        itertools::assert_equal(recipients, section.authority_provider().peers());
 
         Ok(())
     }
@@ -413,8 +412,8 @@ mod tests {
         let (recipients, dg_size) = delivery_targets(&dst, &our_name, &section, &network)?;
 
         // Send to all elders
-        assert_eq!(dg_size, section.elders_info().elders.len());
-        itertools::assert_equal(&recipients, section.elders_info().peers());
+        assert_eq!(dg_size, section.authority_provider().elders.len());
+        itertools::assert_equal(recipients, section.authority_provider().peers());
 
         Ok(())
     }
@@ -430,8 +429,8 @@ mod tests {
         let (recipients, dg_size) = delivery_targets(&dst, &our_name, &section, &network)?;
 
         // Send to all elders
-        assert_eq!(dg_size, section.elders_info().elders.len());
-        itertools::assert_equal(&recipients, section.elders_info().peers());
+        assert_eq!(dg_size, section.authority_provider().elders.len());
+        itertools::assert_equal(recipients, section.authority_provider().peers());
 
         Ok(())
     }
@@ -444,11 +443,11 @@ mod tests {
         let pk = sk.public_key();
         let chain = SectionChain::new(pk);
 
-        let (elders_info0, _) = gen_elders_info(prefix0, ELDER_SIZE);
-        let elders0: Vec<_> = elders_info0.peers().copied().collect();
-        let elders_info0 = proven(&sk, elders_info0)?;
+        let (section_auth0, _) = gen_section_authority_provider(prefix0, ELDER_SIZE);
+        let elders0: Vec<_> = section_auth0.peers().collect();
+        let section_auth0 = proven(&sk, section_auth0)?;
 
-        let mut section = Section::new(pk, chain, elders_info0)?;
+        let mut section = Section::new(pk, chain, section_auth0)?;
 
         for peer in elders0 {
             let member_info = MemberInfo::joined(peer);
@@ -458,11 +457,11 @@ mod tests {
 
         let mut network = Network::new();
 
-        let (elders_info1, _) = gen_elders_info(prefix1, ELDER_SIZE);
-        let elders_info1 = proven(&sk, elders_info1)?;
-        assert!(network.update_section(elders_info1, None, section.chain()));
+        let (section_auth1, _) = gen_section_authority_provider(prefix1, ELDER_SIZE);
+        let section_auth1 = proven(&sk, section_auth1)?;
+        assert!(network.update_section(section_auth1, None, section.chain()));
 
-        let our_name = choose_elder_name(section.elders_info())?;
+        let our_name = choose_elder_name(section.authority_provider())?;
 
         Ok((our_name, section, network, sk))
     }
@@ -474,9 +473,9 @@ mod tests {
         let pk = sk.public_key();
         let chain = SectionChain::new(pk);
 
-        let (elders_info, _) = gen_elders_info(prefix0, ELDER_SIZE);
-        let elders_info = proven(&sk, elders_info)?;
-        let section = Section::new(pk, chain, elders_info)?;
+        let (section_auth, _) = gen_section_authority_provider(prefix0, ELDER_SIZE);
+        let section_auth = proven(&sk, section_auth)?;
+        let section = Section::new(pk, chain, section_auth)?;
 
         let network = Network::new();
         let our_name = section.prefix().substituted_in(rand::random());
@@ -484,8 +483,8 @@ mod tests {
         Ok((our_name, section, network))
     }
 
-    fn choose_elder_name(elders_info: &EldersInfo) -> Result<XorName> {
-        elders_info
+    fn choose_elder_name(section_auth: &SectionAuthorityProvider) -> Result<XorName> {
+        section_auth
             .elders
             .keys()
             .choose(&mut rand::thread_rng())
